# probcalc

![Tests](https://github.com/DoctorDalek1963/probcalc/actions/workflows/tests.yaml/badge.svg)
![Linting](https://github.com/DoctorDalek1963/probcalc/actions/workflows/linting.yaml/badge.svg)
![Type Checks](https://github.com/DoctorDalek1963/probcalc/actions/workflows/type_checks.yaml/badge.svg)
![Docstrings](https://github.com/DoctorDalek1963/probcalc/actions/workflows/docstrings.yaml/badge.svg)

![GPLv3 License](https://img.shields.io/github/license/DoctorDalek1963/probcalc?style=flat-square)
![Latest commit](https://img.shields.io/github/last-commit/DoctorDalek1963/probcalc?style=flat-square)
![Code size](https://img.shields.io/github/languages/code-size/DoctorDalek1963/probcalc?style=flat-square)
![Repo size](https://img.shields.io/github/repo-size/DoctorDalek1963/probcalc?style=flat-square)

---

This is the `probcalc` Python package, which is designed to provide a way to easily
calculate probabilities for random variables distributed by various probability distributions.

The Python source code can be found in `src/probcalc/` and the full documentation can be
found on [my GitHub pages site](https://doctordalek1963.github.io/probcalc).

This project is also available [on PyPI](https://pypi.org/project/probcalc/) and can
be installed simply with `pip install probcalc`.
